.. sluyspy documentation master file, created by
   sphinx-quickstart on Sun Oct  8 11:30:09 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sluyspy's documentation!
===================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:
   
   sluyspy



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
